@@ -120,21 +120,6 @@ sub doFilter {
 	return grep { !$TL->newValue($_)->isHira() } @$values;
 }
 
-# -----------------------------------------------------------------------------
-# Tripletail::Validator::Filter::HtmlTag - HtmlTagフィルタ
-# -----------------------------------------------------------------------------
-package Tripletail::Validator::Filter::HtmlTag;
-use Tripletail;
-
-use base qw{Tripletail::Validator::Filter};
-
-sub doFilter {
-	my $this   = shift;
-	my $values = shift;
-
-	return grep { !$TL->newValue($_)->isHtmlTag() } @$values;
-}
-
 # -----------------------------------------------------------------------------
 # Tripletail::Validator::Filter::HttpsUrl - HttpsUrlフィルタ
 # -----------------------------------------------------------------------------
@@ -185,7 +170,9 @@ sub doFilter {
 	my $this   = shift;
 	my $values = shift;
 	my $args   = shift;
-
+	
+	@$values or return 'no items';
+	
 	my ( $min, $max ) =
 	  defined($args) ? map { $_ ne '' ? $_ : undef } split( ',', $args ) : ();
 	return grep { !$TL->newValue($_)->isInteger( $min, $max ) } @$values;
@@ -254,6 +241,53 @@ sub doFilter {
 	return grep { !$TL->newValue($_)->isMobileEmail() } @$values;
 }
 
+# -----------------------------------------------------------------------------
+# Tripletail::Validator::Filter::Blank - Blankフィルタ
+# -----------------------------------------------------------------------------
+package Tripletail::Validator::Filter::Blank;
+use Tripletail;
+
+use base qw{Tripletail::Validator::Filter};
+
+sub doFilter {
+	my $this   = shift;
+	my $values = shift;
+
+	my $notblank = grep {! $TL->newValue($_)->isBlank() } @$values;
+	(@$values != 0 && $notblank) ? undef : [];
+}
+
+# -----------------------------------------------------------------------------
+# Tripletail::Validator::Filter::NotBlank - NotBlankフィルタ
+# -----------------------------------------------------------------------------
+package Tripletail::Validator::Filter::NotBlank;
+use Tripletail;
+
+use base qw{Tripletail::Validator::Filter};
+
+sub doFilter {
+	my $this   = shift;
+	my $values = shift;
+
+	return @$values == 0 || grep {$TL->newValue($_)->isBlank() } @$values;
+}
+
+# -----------------------------------------------------------------------------
+# Tripletail::Validator::Filter::Empty - Emptyフィルタ
+# -----------------------------------------------------------------------------
+package Tripletail::Validator::Filter::Empty;
+use Tripletail;
+
+use base qw{Tripletail::Validator::Filter};
+
+sub doFilter {
+	my $this   = shift;
+	my $values = shift;
+
+	my $notempty = grep {! $TL->newValue($_)->isEmpty() } @$values;
+	(@$values != 0 && $notempty) ? undef : [];
+}
+
 # -----------------------------------------------------------------------------
 # Tripletail::Validator::Filter::NotEmpty - NotEmptyフィルタ
 # -----------------------------------------------------------------------------
@@ -266,7 +300,7 @@ sub doFilter {
 	my $this   = shift;
 	my $values = shift;
 
-	return @$values == 0 || grep { $TL->newValue($_)->isEmpty() } @$values;
+	return @$values == 0 || grep {$TL->newValue($_)->isEmpty() } @$values;
 }
 
 # -----------------------------------------------------------------------------
@@ -422,21 +456,6 @@ sub doFilter {
 	return grep { !$TL->newValue($_)->isTelNumber() } @$values;
 }
 
-# -----------------------------------------------------------------------------
-# Tripletail::Validator::Filter::TrailingSlash - TrailingSlashフィルタ
-# -----------------------------------------------------------------------------
-package Tripletail::Validator::Filter::TrailingSlash;
-use Tripletail;
-
-use base qw{Tripletail::Validator::Filter};
-
-sub doFilter {
-	my $this   = shift;
-	my $values = shift;
-
-	return grep { !$TL->newValue($_)->isTrailingSlash() } @$values;
-}
-
 # -----------------------------------------------------------------------------
 # Tripletail::Validator::Filter::Portable - Portableフィルタ
 # -----------------------------------------------------------------------------
@@ -449,7 +468,23 @@ sub doFilter {
 	my $this   = shift;
 	my $values = shift;
 
-	return grep { $TL->newValue($_)->isUnportable() } @$values;
+	return grep { !$TL->newValue($_)->isPortable() } @$values;
+}
+
+# -----------------------------------------------------------------------------
+# Tripletail::Validator::Filter::IpAddress - IpAddressフィルタ
+# -----------------------------------------------------------------------------
+package Tripletail::Validator::Filter::IpAddress;
+use Tripletail;
+
+use base qw{Tripletail::Validator::Filter};
+
+sub doFilter {
+	my $this   = shift;
+	my $values = shift;
+	my $args   = shift;
+
+	return grep { !$TL->newValue($_)->isIpAddress($args) } @$values;
 }
 
 # -----------------------------------------------------------------------------
